@@ -1,4 +1,4 @@
-# Copyright 2021 Q-CTRL. All rights reserved.
+# Copyright 2022 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -18,6 +18,7 @@ Module for converting Q-CTRL optimized pulses into QUA configurations.
 from typing import (
     Dict,
     List,
+    Optional,
     Union,
 )
 
@@ -30,6 +31,7 @@ def add_pulse_to_config(
     i_signal: Union[List[float], np.ndarray],
     q_signal: Union[List[float], np.ndarray],
     config: Dict,
+    intermediate_frequency: Optional[float] = None,
 ) -> Dict:
     """
     Adds a pulse to the QUA config.
@@ -46,6 +48,12 @@ def add_pulse_to_config(
         Contains Q quadrature of the pulse at 1ns sampling rate
     config : dict
         The main config that contains all parameters of the Operator-X (OPX).
+    intermediate_frequency : float, optional
+        The intermediate frequency of the channel in Mhz. If provided, this
+        value overrides the intermediate frequency of the original `config`
+        dictionary. By default it is `None`, which means that the original
+        value of the intermediary frequency is not modified if it's already
+        present.
 
     Returns
     -------
@@ -59,6 +67,16 @@ def add_pulse_to_config(
     """
     if np.max(np.abs(i_signal)) > 0.49 or np.max(np.abs(q_signal)) > 0.49:
         raise ValueError("max_amplitude must be below 0.49")
+    if "version" not in config:
+        config["version"] = 1
+    if "controllers" not in config:
+        config["controllers"] = {}
+    if "digital_waveforms" not in config:
+        config["digital_waveforms"] = {}
+    if "integration_weights" not in config:
+        config["integration_weights"] = {}
+    if "mixers" not in config:
+        config["mixers"] = {}
     if "waveforms" not in config:
         config["waveforms"] = {}
     if "pulses" not in config:
@@ -69,6 +87,12 @@ def add_pulse_to_config(
         config["elements"][channel_name] = {}
     if "operations" not in config["elements"][channel_name]:
         config["elements"][channel_name]["operations"] = {}
+    if intermediate_frequency is not None:
+        config["elements"][channel_name][
+            "intermediate_frequency"
+        ] = intermediate_frequency
+    if "intermediate_frequency" not in config["elements"][channel_name]:
+        config["elements"][channel_name]["intermediate_frequency"] = None
 
     config["waveforms"][pulse_name + "_I"] = {
         "type": "arbitrary",
